==> notolog-1.0.2-py3-none-any.whl: notolog/lexemes/zh/toolbar.py <==
# Chinese lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "新建文档",
    "actions_accessible_name_new_document": "新文档",
    "actions_label_open": "打开",
    "actions_accessible_name_open": "打开文档",
    "actions_label_save": "保存",
    "actions_accessible_name_save": "保存文档",
    "actions_label_save_as": "另存为",
    "actions_accessible_name_save_as": "另存文档副本",
    "actions_label_sync": "同步",
    "actions_accessible_name_sync": "与外部存储同步文档",
    "actions_label_edit": "编辑",
    "actions_accessible_name_edit": "编辑文件",
    "actions_label_source": "源码",
    "actions_accessible_name_source": "源代码",
    "actions_label_encrypt": "加密",
    "actions_accessible_name_encrypt": "加密文件",
    "actions_label_decrypt": "解密",
    "actions_accessible_name_decrypt": "解密文件",
    "actions_label_bold": "加粗",
    "actions_accessible_name_bold": "加粗文本格式",
    "actions_label_italic": "斜体",
    "actions_accessible_name_italic": "斜体文本格式",
    "actions_label_underline": "下划线",
    "actions_accessible_name_underline": "下划线文本格式",
    "actions_label_strikethrough": "删除线",
    "actions_accessible_name_strikethrough": "删除线文本格式",
    "actions_label_blockquote": "引用",
    "actions_accessible_name_blockquote": "引用文本格式",
    "actions_label_color_picker": "颜色选择器",
    "actions_accessible_name_color_picker": "选择文字颜色",
    "actions_label_ai_assistant": "AI 助手",
    "actions_accessible_name_ai_assistant": "运行 AI 助手",
    "actions_label_about": "关于",
    "actions_accessible_name_about": "关于应用",
    "actions_label_exit": "退出",
    "actions_accessible_name_exit": "退出应用",
    "actions_label_settings": "设置",
    "actions_accessible_name_settings": "应用设置",

    "search_input_label": "搜索",
    "search_input_placeholder_text": "文档中的文本",
    "search_input_accessible_description": "搜索输入字段",
    "search_buttons_label_clear": "清除搜索",
    "search_buttons_accessible_name_clear": "清除搜索输入字段",
    "search_buttons_label_prev": "上一次搜索",
    "search_buttons_accessible_name_prev": "上一次搜索结果",
    "search_buttons_label_next": "下一次搜索",
    "search_buttons_accessible_name_next": "下一次搜索结果",
    "search_case_sensitive_label": "区分大小写",
    "search_case_sensitive_tooltip": "区分大小写的搜索",
}

==> notolog-1.0.7-py3-none-any.whl: notolog/lexemes/zh/toolbar.py <==
# Chinese lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "新建文档",
    "actions_accessible_name_new_document": "新文档",
    "actions_label_open": "打开",
    "actions_accessible_name_open": "打开文档",
    "actions_label_save": "保存",
    "actions_accessible_name_save": "保存文档",
    "actions_label_save_as": "另存为",
    "actions_accessible_name_save_as": "另存文档副本",
    "actions_label_sync": "同步",
    "actions_accessible_name_sync": "与外部存储同步文档",
    "actions_label_edit": "编辑",
    "actions_accessible_name_edit": "编辑文件",
    "actions_label_source": "源码",
    "actions_accessible_name_source": "源代码",
    "actions_label_encrypt": "加密",
    "actions_accessible_name_encrypt": "加密文件",
    "actions_label_decrypt": "解密",
    "actions_accessible_name_decrypt": "解密文件",
    "actions_label_bold": "加粗",
    "actions_accessible_name_bold": "加粗文本格式",
    "actions_label_italic": "斜体",
    "actions_accessible_name_italic": "斜体文本格式",
    "actions_label_underline": "下划线",
    "actions_accessible_name_underline": "下划线文本格式",
    "actions_label_strikethrough": "删除线",
    "actions_accessible_name_strikethrough": "删除线文本格式",
    "actions_label_blockquote": "引用",
    "actions_accessible_name_blockquote": "引用文本格式",
    "actions_label_color_picker": "颜色选择器",
    "actions_accessible_name_color_picker": "选择文字颜色",
    "actions_label_ai_assistant": "AI 助手",
    "actions_accessible_name_ai_assistant": "运行 AI 助手",
    "actions_label_about": "关于",
    "actions_accessible_name_about": "关于应用",
    "actions_label_exit": "退出",
    "actions_accessible_name_exit": "退出应用",
    "actions_label_settings": "设置",
    "actions_accessible_name_settings": "应用设置",

    "search_input_label": "搜索",
    "search_input_placeholder_text": "在文档中搜索文本",
    "search_input_accessible_description": "搜索输入字段",
    "search_buttons_label_clear": "清除搜索",
    "search_buttons_accessible_name_clear": "清除搜索输入字段",
    "search_buttons_label_prev": "上一次搜索",
    "search_buttons_accessible_name_prev": "上一次搜索结果",
    "search_buttons_label_next": "下一次搜索",
    "search_buttons_accessible_name_next": "下一次搜索结果",
    "search_case_sensitive_accessible_name": "区分大小写",
    "search_case_sensitive_tooltip": "区分大小写的搜索",
}
